==> kdevplatform_1.6.0.orig.tar.xz: kdevplatform-1.6.0/sublime/examples/example2main.h <==
/***************************************************************************
 *   Copyright 2007 Alexander Dymo <adymo@kdevelop.org>                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#ifndef KDEVPLATFORM_EXAMPLE2MAIN_H
#define KDEVPLATFORM_EXAMPLE2MAIN_H

#include <sublime/mainwindow.h>

class Example2Main: public Sublime::MainWindow {
    Q_OBJECT

public:
    explicit Example2Main(Sublime::Controller *controller, Qt::WindowFlags flags = KDE_DEFAULT_WINDOWFLAGS);

public slots:
    void splitVertical();
    void splitHorizontal();
    void close();

};

#endif

==> kdevplatform-5.1.2.tar.xz: kdevplatform-5.1.2/sublime/examples/example2main.h <==
/***************************************************************************
 *   Copyright 2007 Alexander Dymo <adymo@kdevelop.org>                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#ifndef KDEVPLATFORM_EXAMPLE2MAIN_H
#define KDEVPLATFORM_EXAMPLE2MAIN_H

#include <sublime/mainwindow.h>

class Example2Main: public Sublime::MainWindow {
    Q_OBJECT

public:
    explicit Example2Main(Sublime::Controller *controller, Qt::WindowFlags flags = {});

public slots:
    void splitVertical();
    void splitHorizontal();
    void close();

};

#endif
